# Changelog

## [0.4.2](https://github.com/noshita/ktch/compare/v0.4.1...v0.4.2) (2024-06-09)


### Bug Fixes

* 🐛  inefficient regular expression ([a2d04a2](https://github.com/noshita/ktch/commit/a2d04a2de7bbf204e289e2c2e4cdf75b0a59565f))
* 🐛 actions/setup-python ([d06a63e](https://github.com/noshita/ktch/commit/d06a63e8fc558f66d3dcce14393bddbe32b7372e))
* 🐛 install jupytext ([b938cb1](https://github.com/noshita/ktch/commit/b938cb1e52a77191069538942caeb71f46c07c1f))
* 🐛 invalid escape sequence ([394464d](https://github.com/noshita/ktch/commit/394464d84c1ec0da8fd50c12bd4a93c80afbe31c))


### Documentation

* 📚 introduce jupytext and remove .ipynb files ([d8b38b9](https://github.com/noshita/ktch/commit/d8b38b9a11408da1fd464a0f2c7b268688c23350))
* 📚 introduce jupytext and remove .ipynb files ([0d6dd70](https://github.com/noshita/ktch/commit/0d6dd705a53a52495e15e945612b4185ffd2b0a5))


### Miscellaneous Chores

* 🔧 update requirements.txt ([a43ec5f](https://github.com/noshita/ktch/commit/a43ec5f7ec020c338cb04bf87c8f22020c081f60))
* release 0.4.1 ([cc1c2a6](https://github.com/noshita/ktch/commit/cc1c2a62aeaebf444b14e05285378e6de8463860))

## [0.4.1](https://github.com/noshita/ktch/compare/v0.4.1...v0.4.1) (2024-03-12)


### Bug Fixes

* 🐛  inefficient regular expression ([a2d04a2](https://github.com/noshita/ktch/commit/a2d04a2de7bbf204e289e2c2e4cdf75b0a59565f))
* 🐛 install jupytext ([b938cb1](https://github.com/noshita/ktch/commit/b938cb1e52a77191069538942caeb71f46c07c1f))
* 🐛 invalid escape sequence ([394464d](https://github.com/noshita/ktch/commit/394464d84c1ec0da8fd50c12bd4a93c80afbe31c))


### Documentation

* 📚 introduce jupytext and remove .ipynb files ([d8b38b9](https://github.com/noshita/ktch/commit/d8b38b9a11408da1fd464a0f2c7b268688c23350))
* 📚 introduce jupytext and remove .ipynb files ([0d6dd70](https://github.com/noshita/ktch/commit/0d6dd705a53a52495e15e945612b4185ffd2b0a5))


### Miscellaneous Chores

* release 0.4.1 ([cc1c2a6](https://github.com/noshita/ktch/commit/cc1c2a62aeaebf444b14e05285378e6de8463860))

## [0.3.3](https://github.com/noshita/ktch/compare/v0.3.2...v0.3.3) (2024-03-10)


### Features

* ✨ add to doc ([25317da](https://github.com/noshita/ktch/commit/25317da0805b13316e767a563460c597da2066a9))
* ✨ add tps transformation grid ([ae87df5](https://github.com/noshita/ktch/commit/ae87df55d6f9590ac11f1be94ab493c647f71980))
* ✨ add tps transformation grid ([d295a4f](https://github.com/noshita/ktch/commit/d295a4fbc1629475b1fb4f85a569e4b178704f75))
* ✨ thin-plate spline ([09f8c4a](https://github.com/noshita/ktch/commit/09f8c4a4c7cd6061e8a55939b9cb1801386267ca))

## [0.3.1](https://github.com/noshita/ktch/compare/v0.3.0...v0.3.1) (2024-02-08)


### Bug Fixes

* 🐛 phase shift ([25450bc](https://github.com/noshita/ktch/commit/25450bc4f112f0f81e9ba34d4d832275302320be))
* 🐛 phaseshift ([25450bc](https://github.com/noshita/ktch/commit/25450bc4f112f0f81e9ba34d4d832275302320be))
* 🐛 phaseshift ([25450bc](https://github.com/noshita/ktch/commit/25450bc4f112f0f81e9ba34d4d832275302320be))
* 🐛 setter of SPHARMCoefficients class ([ee12ce2](https://github.com/noshita/ktch/commit/ee12ce2e62243c48ac657b322f62fb9fe0ee4231))


### Documentation

* 📚 add robots.txt ([ff2aeda](https://github.com/noshita/ktch/commit/ff2aedaf031ca032dac0b8daf40c170a40cb1b3a))
* 📚 add sitemap ([8ea64cf](https://github.com/noshita/ktch/commit/8ea64cffe07cac0f3a11734b7c94eaec511e60e1))
* 📚 doc ([ceb1ee3](https://github.com/noshita/ktch/commit/ceb1ee310ce9b00f13b836592ea73a39074b43a9))
* 📚 update autodoc ([ba2c2d6](https://github.com/noshita/ktch/commit/ba2c2d6cc66325fbbf6758a5ad260f1c723fb116))
* 📚 update doc config ([72f6df7](https://github.com/noshita/ktch/commit/72f6df73d8d7ce97644382a6b26e22eefbb00c39))
* 📚 update favicon ([54b6cec](https://github.com/noshita/ktch/commit/54b6cec17a9ac894ebcabfde7514722b4c046712))
* 📚 update favicon ([54b6cec](https://github.com/noshita/ktch/commit/54b6cec17a9ac894ebcabfde7514722b4c046712))
* 📚 update favicon ([54b6cec](https://github.com/noshita/ktch/commit/54b6cec17a9ac894ebcabfde7514722b4c046712))
